==> icedtea-web_1.4.orig.tar.gz: icedtea-web-1.4/netx/net/sourceforge/jnlp/splashscreen/impls/DefaultErrorSplashScreen2012.java <==
/* DefaultErrorSplashScreen12.java
Copyright (C) 2012 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */
package net.sourceforge.jnlp.splashscreen.impls;

import java.awt.Graphics;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import net.sourceforge.jnlp.splashscreen.SplashUtils.SplashReason;
import net.sourceforge.jnlp.splashscreen.impls.defaultsplashscreen2012.ErrorPainter;
import net.sourceforge.jnlp.splashscreen.parts.BasicComponentErrorSplashScreen;

public final class DefaultErrorSplashScreen2012 extends BasicComponentErrorSplashScreen {

    private final DefaultErrorSplashScreen2012 self;
    private final ErrorPainter painter;
    private final DefaultSplashScreens2012Commons commons;

    public DefaultErrorSplashScreen2012(int width, int height, SplashReason splashReason, Throwable ex) {
        //setting width and height now is causing  unnecessary blinking
        //setSplashHeight(height);
        //setSplashWidth(width);
        //to have this in inner classes
        self = this;
        setLoadingException(ex);
        setSplashReason(splashReason);
        painter = new ErrorPainter(self, true);
        addMouseListener(new MouseAdapter() {

            @Override
            public void mouseClicked(MouseEvent e) {
                if (((ErrorPainter) painter).getErrorCorner() != null
                        && e.getX() > ((ErrorPainter) painter).getErrorCorner().x
                        && e.getY() > ((ErrorPainter) painter).getErrorCorner().y) {
                    raiseExceptionDialog();
                }
            }
        });
        commons = new DefaultSplashScreens2012Commons(painter, self);
    }

    @Override
    public void paintComponent(Graphics g) {
        paintTo(g);
    }

    @Override
    public void paintTo(Graphics g) {
        commons.paintTo(g);


    }

    @Override
    public void adjustForSize() {
        commons.adjustForSize();
    }

    @Override
    public void stopAnimation() {
        commons.stopAnimation();
    }

    /**
     * Methods to start the animation in the splash panel.
     *
     * This method exits after starting a new thread to do the animation. It
     * is synchronized to prevent multiple startAnimation threads from being created.
     */
    @Override
    public void startAnimation() {
        commons.startAnimation();
    }

    @Override
    public void setPercentage(int done) {
       commons.setPercentage(done);
    }

    @Override
    public int getPercentage() {
        return commons.getPercentage();
    }
}

==> icedtea-web_1.6.2.orig.tar.gz: icedtea-web-1.6.2/netx/net/sourceforge/jnlp/splashscreen/impls/DefaultErrorSplashScreen2012.java <==
/* DefaultErrorSplashScreen12.java
Copyright (C) 2012 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */
package net.sourceforge.jnlp.splashscreen.impls;

import java.awt.Graphics;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import net.sourceforge.jnlp.splashscreen.SplashUtils.SplashReason;
import net.sourceforge.jnlp.splashscreen.impls.defaultsplashscreen2012.ErrorPainter;
import net.sourceforge.jnlp.splashscreen.parts.BasicComponentErrorSplashScreen;

public final class DefaultErrorSplashScreen2012 extends BasicComponentErrorSplashScreen {

    private final ErrorPainter painter;
    private final DefaultSplashScreens2012Commons commons;

    public DefaultErrorSplashScreen2012(int width, int height, SplashReason splashReason, Throwable ex) {
        //setting width and height now is causing  unnecessary blinking
        //setSplashHeight(height);
        //setSplashWidth(width);
        //to have this in inner classes
        setLoadingException(ex);
        setSplashReason(splashReason);
        painter = new ErrorPainter(this, true);
        addMouseListener(new MouseAdapter() {

            @Override
            public void mouseClicked(MouseEvent e) {
                if ((painter).getErrorCorner() != null
                        && e.getX() > (painter).getErrorCorner().x
                        && e.getY() > (painter).getErrorCorner().y) {
                    raiseExceptionDialog();
                }
            }
        });
        commons = new DefaultSplashScreens2012Commons(painter, this);
    }

    @Override
    public void paintComponent(Graphics g) {
        paintTo(g);
    }

    @Override
    public void paintTo(Graphics g) {
        commons.paintTo(g);


    }

    @Override
    public void adjustForSize() {
        commons.adjustForSize();
    }

    @Override
    public void stopAnimation() {
        commons.stopAnimation();
    }

    /**
     * Methods to start the animation in the splash panel.
     *
     * This method exits after starting a new thread to do the animation. It
     * is synchronized to prevent multiple startAnimation threads from being created.
     */
    @Override
    public void startAnimation() {
        commons.startAnimation();
    }

    @Override
    public void setPercentage(int done) {
       commons.setPercentage(done);
    }

    @Override
    public int getPercentage() {
        return commons.getPercentage();
    }
}
